@@ -4,8 +4,9 @@ describe 'nova::api' do
 
   let :pre_condition do
     "include nova
-     class { '::nova::keystone::authtoken':
+     class { 'nova::keystone::authtoken':
        password => 'passw0rd',
+       params => { 'username' => 'novae' },
      }"
   end
 
@@ -143,7 +144,7 @@ describe 'nova::api' do
         })
       end
       it { is_expected.to contain_openstacklib__service_validation('nova-api').with(
-        :command   => 'nova --os-auth-url http://127.0.0.1:5000/ --os-project-name services --os-username nova --os-password passw0rd flavor-list',
+        :command   => 'nova --os-auth-url http://127.0.0.1:5000/ --os-project-name services --os-username novae --os-password passw0rd flavor-list',
         :subscribe => 'Service[nova-api]',
       )}
 
@@ -175,8 +176,8 @@ describe 'nova::api' do
 
     context 'with default database parameters' do
       let :pre_condition do
-        "include nova
-         class { '::nova::keystone::authtoken':
+        "include nova::db
+         class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -190,14 +191,14 @@ describe 'nova::api' do
 
     context 'with overridden database parameters' do
       let :pre_condition do
-        "class { 'nova':
-           database_connection     => 'mysql://user:pass@db/db1',
-           slave_connection        => 'mysql://user:pass@slave/db1',
-           api_database_connection => 'mysql://user:pass@db/db2',
-           api_slave_connection    => 'mysql://user:pass@slave/db2',
-           database_idle_timeout   => '30',
+        "class { 'nova::db':
+           database_connection              => 'mysql://user:pass@db/db1',
+           slave_connection                 => 'mysql://user:pass@slave/db1',
+           api_database_connection          => 'mysql://user:pass@db/db2',
+           api_slave_connection             => 'mysql://user:pass@slave/db2',
+           database_connection_recycle_time => '30',
          }
-         class { '::nova::keystone::authtoken':
+         class { 'nova::keystone::authtoken':
            password => 'passw0rd',
          }
         "
@@ -229,9 +230,9 @@ describe 'nova::api' do
       end
 
       let :pre_condition do
-        "include ::apache
-         include ::nova
-         class { '::nova::keystone::authtoken':
+        "include apache
+         include nova
+         class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -257,9 +258,9 @@ describe 'nova::api' do
       end
 
       let :pre_condition do
-        "include ::apache
-         include ::nova
-         class { '::nova::keystone::authtoken':
+        "include apache
+         include nova
+         class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -282,9 +283,9 @@ describe 'nova::api' do
       end
 
       let :pre_condition do
-        "include ::apache
-         include ::nova
-         class { '::nova::keystone::authtoken':
+        "include apache
+         include nova
+         class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
@@ -315,9 +316,9 @@ describe 'nova::api' do
       end
 
       let :pre_condition do
-        "include ::apache
-         include ::nova
-         class { '::nova::keystone::authtoken':
+        "include apache
+         include nova
+         class { 'nova::keystone::authtoken':
            password => 'a_big_secret',
          }"
       end
