@@ -53,6 +53,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/cpu_model').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/snapshots_directory').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
@@ -83,6 +84,7 @@ describe 'nova::compute::libvirt' do
           :cpu_models                                 => ['kvm64', 'qemu64'],
           :cpu_model_extra_flags                      => 'pcid',
           :snapshot_image_format                      => 'raw',
+          :snapshots_directory                        => '/var/lib/nova/snapshots',
           :disk_cachemodes                            => ['file=directsync','block=none'],
           :hw_disk_discard                            => 'unmap',
           :hw_machine_type                            => 'x86_64=machinetype1,armv7l=machinetype2',
@@ -121,6 +123,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/cpu_model').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('pcid')}
       it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('raw')}
+      it { is_expected.to contain_nova_config('libvirt/snapshots_directory').with_value('/var/lib/nova/snapshots')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_value('file=directsync,block=none')}
       it { is_expected.to contain_nova_config('libvirt/hw_disk_discard').with_value('unmap')}
       it { is_expected.to contain_nova_config('libvirt/hw_machine_type').with_value('x86_64=machinetype1,armv7l=machinetype2')}
@@ -213,7 +216,6 @@ describe 'nova::compute::libvirt' do
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
         it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
-        it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => libvirt_options) }
       end
 
       context 'with vncserver_listen set to ::0' do
@@ -224,17 +226,6 @@ describe 'nova::compute::libvirt' do
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
         it { is_expected.to contain_nova_config('vnc/server_listen').with_value('::0')}
-        it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => libvirt_options) }
-      end
-
-      context 'with custom libvirt service name on Debian platforms' do
-        let :params do
-          { :libvirt_service_name  => 'libvirtd',
-            :vncserver_listen      => '0.0.0.0',
-            :migration_support     => true }
-        end
-        it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => libvirt_options) }
-
       end
     end
 
@@ -324,7 +315,6 @@ describe 'nova::compute::libvirt' do
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
         it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
-        it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(:line => 'LIBVIRTD_ARGS="--listen"') }
       end
 
       context 'with vncserver_listen set to ::0' do
@@ -335,7 +325,6 @@ describe 'nova::compute::libvirt' do
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
         it { is_expected.to contain_nova_config('vnc/server_listen').with_value('::0')}
-        it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(:line => 'LIBVIRTD_ARGS="--listen"') }
       end
 
     end
