@@ -6,6 +6,9 @@ describe 'nova' do
 
     context 'with default parameters' do
 
+      it { is_expected.to contain_class('nova::deps') }
+      it { is_expected.to contain_class('nova::workarounds') }
+
       it 'installs packages' do
         is_expected.to contain_package('python-nova').with(
           :ensure => 'present',
@@ -119,6 +122,9 @@ describe 'nova' do
         }
       end
 
+      it { is_expected.to contain_class('nova::deps') }
+      it { is_expected.to contain_class('nova::workarounds') }
+
       it 'installs packages' do
         is_expected.to contain_package('nova-common').with('ensure' => '2012.1.1-15.el6')
         is_expected.to contain_package('python-nova').with('ensure' => '2012.1.1-15.el6')
@@ -305,7 +311,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')
