@@ -40,8 +40,11 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_with_native_tls').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_post_copy').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_auto_converge').with_value('<SERVICE DEFAULT>')}
     end
 
     context 'with override_uuid enabled' do
@@ -61,6 +64,24 @@ describe 'nova::migration::libvirt' do
       }).that_requires('Package[libvirt]').that_notifies('Service[libvirt]') }
     end
 
+    context 'with override_uuid enabled and host_uuid set' do
+      let :params do
+        {
+          :override_uuid => true,
+          :host_uuid => 'a8debd9d-e359-4bb2-8c77-edee431f94f2',
+        }
+      end
+
+      it { is_expected.to contain_file('/etc/libvirt/libvirt_uuid').with({
+        :content => 'a8debd9d-e359-4bb2-8c77-edee431f94f2',
+      }).that_requires('Package[libvirt]') }
+
+      it { is_expected.to contain_augeas('libvirt-conf-uuid').with({
+        :context => '/files/etc/libvirt/libvirtd.conf',
+        :changes => [ "set host_uuid a8debd9d-e359-4bb2-8c77-edee431f94f2" ],
+      }).that_requires('Package[libvirt]').that_notifies('Service[libvirt]') }
+    end
+
     context 'with tls enabled' do
       let :params do
         {
@@ -103,10 +124,23 @@ describe 'nova::migration::libvirt' do
         {
           :live_migration_tunnelled          => true,
           :live_migration_completion_timeout => '1500',
+          :live_migration_timeout_action     => 'force_complete',
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with(:value => true) }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('1500') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('force_complete') }
+    end
+
+    context 'with live migration auto converge on' do
+      let :params do
+        {
+          :live_migration_permit_post_copy     => false,
+          :live_migration_permit_auto_converge => true,
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_post_copy').with(:value => false) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_permit_auto_converge').with(:value => true) }
     end
 
     context 'with auth set to sasl' do
